summaryrefslogtreecommitdiffstats
path: root/libhb/rendersub.c
diff options
context:
space:
mode:
authorjstebbins <[email protected]>2014-01-26 18:01:50 +0000
committerjstebbins <[email protected]>2014-01-26 18:01:50 +0000
commit96fbc744385ddcc15617ba449d1521c30f66da3d (patch)
tree00a351c416a2307e511042d0a86bf4d3a2bfe7d1 /libhb/rendersub.c
parent1d7db22df59be148ed995eee7755f21d8f0b9d5b (diff)
Replace invaled timestamp flag "-1" with AV_NOPTS
-1 is not a good value as a flag for invalid timestamps. There are cases where small negative timestamps are useful. So this eliminates a potential ambiguity. git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@6001 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'libhb/rendersub.c')
-rw-r--r--libhb/rendersub.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libhb/rendersub.c b/libhb/rendersub.c
index f42bdf8eb..7d45e315c 100644
--- a/libhb/rendersub.c
+++ b/libhb/rendersub.c
@@ -258,8 +258,8 @@ static void ApplyVOBSubs( hb_filter_private_t * pv, hb_buffer_t * buf )
else
next = NULL;
- if ((sub->s.stop != -1 && sub->s.stop <= buf->s.start) ||
- (next != NULL && sub->s.stop == -1 && next->s.start <= buf->s.start))
+ if ((sub->s.stop != AV_NOPTS_VALUE && sub->s.stop <= buf->s.start) ||
+ (next != NULL && sub->s.stop == AV_NOPTS_VALUE && next->s.start <= buf->s.start))
{
// Subtitle stop is in the past, delete it
hb_list_rem( pv->sub_list, sub );
@@ -548,7 +548,7 @@ static int ssa_work( hb_filter_object_t * filter,
{
// Parse MKV-SSA packet
// SSA subtitles always have an explicit stop time, so we
// do not need to do special processing for stop == -1
ass_process_chunk( pv->ssaTrack, (char*)sub->data, sub->size,
sub->s.start / 90,
(sub->s.stop - sub->s.start) / 90 );
@@ -548,7 +548,7 @@ static int ssa_work( hb_filter_object_t * filter,
// Parse MKV-SSA packet
// SSA subtitles always have an explicit stop time, so we
- // do not need to do special processing for stop == -1
+ // do not need to do special processing for stop == AV_NOPTS_VALUE
ass_process_chunk( pv->ssaTrack, (char*)sub->data, sub->size,
sub->s.start / 90,